changeset 16884:36babc489b0c

Change all uses of win95, winnt, and win32 into Windows 95, Windows NT, and W32, respectively. Expand "win" substring in variables referring to Microsoft Windows constructs into "windows". Canonicalize header comments to use same terminology.
author Geoff Voelker <voelker@cs.washington.edu>
date Mon, 20 Jan 1997 00:38:22 +0000
parents d1d4d81f9ece
children ddd632f61ce3
files src/w32.c src/w32faces.c src/w32fns.c src/w32heap.c src/w32inevt.c src/w32menu.c src/w32proc.c src/w32select.c src/w32term.c src/w32xfns.c
diffstat 10 files changed, 44 insertions(+), 44 deletions(-) [+]
line wrap: on
line diff
--- a/src/w32faces.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32faces.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* "Face" primitives under the Win32 API.
+/* "Face" primitives on the Microsoft W32 API.
    Copyright (C) 1993, 1994, 1995 Free Software Foundation.
 
 This file is part of GNU Emacs.
--- a/src/w32heap.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32heap.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Heap management routines for GNU Emacs on Windows NT.
+/* Heap management routines for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1994 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -107,12 +107,12 @@
      the initial default process heap size and the executable image base
      address.  The link settings and the malloc heap base below must all
      correspond; the relationship between these values depends on how NT
-     and Win95 arrange the virtual address space for a process (and on
+     and Windows 95 arrange the virtual address space for a process (and on
      the size of the code and data segments in temacs.exe).
 
      The most important thing is to make base address for the executable
      image high enough to leave enough room between it and the 4MB floor
-     of the process address space on Win95 for the primary thread stack,
+     of the process address space on Windows 95 for the primary thread stack,
      the process default heap, and other assorted odds and ends
      (eg. environment strings, private system dll memory etc) that are
      allocated before temacs has a chance to grab its malloc arena.  The
@@ -132,7 +132,7 @@
      we will have plenty of room for expansion.
 
      Thus we would like to set the malloc heap base to 20MB.  However,
-     Win95 refuses to allocate the heap starting at this address, so we
+     Windows 95 refuses to allocate the heap starting at this address, so we
      set the base to 27MB to make it happy.  Since Emacs now leaves
      28 bits available for pointers, this lets us use the remainder of
      the region below the 256MB line for our malloc arena - 229MB is
--- a/src/w32inevt.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32inevt.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Input event support for Emacs under Win32 API.
+/* Input event support for Emacs on the Microsoft W32 API.
    Copyright (C) 1992, 1993, 1995 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
--- a/src/w32menu.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32menu.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* X Communication module for terminals which understand the X protocol.
+/* Menu support for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1986, 1988, 1993, 1994 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
--- a/src/w32proc.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32proc.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Process support for Windows NT port of GNU EMACS.
+/* Process support for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1992, 1995 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -58,7 +58,7 @@
 /* Time to sleep before reading from a subprocess output pipe - this
    avoids the inefficiency of frequently reading small amounts of data.
    This is primarily necessary for handling DOS processes on Windows 95,
-   but is useful for W32 processes on both Win95 and NT as well.  */
+   but is useful for W32 processes on both Windows 95 and NT as well.  */
 Lisp_Object Vw32_pipe_read_delay;
 
 /* Control conversion of upper case file names to lower case.
@@ -1112,7 +1112,7 @@
       /* Kill the process.  On W32 this doesn't kill child processes
 	 so it doesn't work very well for shells which is why it's not
 	 used in every case.  Also, don't try to terminate DOS processes
-	 (on Win95), because this will hang Emacs. */
+	 (on Windows 95), because this will hang Emacs. */
       if (!(cp && cp->is_dos_process)
 	  && !TerminateProcess (proc_hand, 0xff))
         {
--- a/src/w32select.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32select.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Selection processing for Emacs using the Win32 API.
+/* Selection processing for Emacs on the Microsoft W32 API.
    Copyright (C) 1993, 1994 Free Software Foundation.
    
 This file is part of GNU Emacs.
--- a/src/w32xfns.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32xfns.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Functions taken directly from X sources for use with the Win32 API.
+/* Functions taken directly from X sources for use with the Microsoft W32 API.
    Copyright (C) 1989, 1992, 1993, 1994, 1995 Free Software Foundation.
 
 This file is part of GNU Emacs.
--- a/src/w32.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Utility and Unix shadow routines for GNU Emacs on Windows NT.
+/* Utility and Unix shadow routines for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1994, 1995 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -1063,17 +1063,17 @@
   char temp[MAX_PATH];
   DWORD attr;
 
   /* MoveFile on Win95 doesn't correctly change the short file name
      alias in a number of circumstances (it is not easy to predict when
      just by looking at oldname and newname, unfortunately).  In these
      cases, renaming through a temporary name avoids the problem.
 
-     A second problem on Win95 is that renaming through a temp name when
+     A second problem on Windows 95 is that renaming through a temp name when
      newname is uppercase fails (the final long name ends up in
      lowercase, although the short alias might be uppercase) UNLESS the
      long temp name is not 8.3.
 
-     So, on Win95 we always rename through a temp name, and we make sure
+     So, on Windows 95 we always rename through a temp name, and we make sure
      the temp name has a long extension to ensure correct renaming.  */
 
   strcpy (temp, map_w32_filename (oldname, NULL));
@@ -1827,7 +1827,7 @@
     }
 
   /* Note that sockets do not need special treatment here (at least on
-     NT and Win95 using the standard tcp/ip stacks) - it appears that
+     NT and Windows 95 using the standard tcp/ip stacks) - it appears that
      closesocket is equivalent to CloseHandle, which is to be expected
      because socket handles are fully fledged kernel handles. */
   rc = _close (fd);
@@ -1965,7 +1965,7 @@
       rc = _read (fd, &cp->chr, sizeof (char));
 
       /* Give subprocess time to buffer some more output for us before
-	 reporting that input is available; we need this because Win95
+	 reporting that input is available; we need this because Windows 95
 	 connects DOS programs to pipes by making the pipe appear to be
 	 the normal console stdout - as a result most DOS programs will
 	 write to stdout without buffering, ie.  one character at a
@@ -1063,17 +1063,17 @@
   DWORD attr;
 
-  /* MoveFile on Win95 doesn't correctly change the short file name
+  /* MoveFile on Windows 95 doesn't correctly change the short file name
      alias in a number of circumstances (it is not easy to predict when
      just by looking at oldname and newname, unfortunately).  In these
--- a/src/w32fns.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32fns.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Functions for the MS Win32 window system API.
+/* Graphical user interface functions for the Microsoft W32 API.
    Copyright (C) 1989, 92, 93, 94, 95, 1996 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -2680,7 +2680,7 @@
   post_msg (wmsg);
 }
 
 /* GetKeyState and MapVirtualKey on Win95 do not actually distinguish
    between left and right keys as advertised.  We test for this
    support dynamically, and set a flag when the support is absent.  If
    absent, we keep track of the left and right control and alt keys
@@ -2879,7 +2879,7 @@
 /* Main message dispatch loop. */
 
 DWORD 
-win_msg_worker (dw)
+windows_msg_worker (dw)
      DWORD dw;
 {
   MSG msg;
@@ -3033,10 +3033,10 @@
 
       if (windows_translate)
 	{
-	  MSG winmsg = { hwnd, msg, wParam, lParam, 0, {0,0} };
-
-	  winmsg.time = GetMessageTime ();
-	  TranslateMessage (&winmsg);
+	  MSG windows_msg = { hwnd, msg, wParam, lParam, 0, {0,0} };
+
+	  windows_msg.time = GetMessageTime ();
+	  TranslateMessage (&windows_msg);
 	  goto dflt;
 	}
 
@@ -3257,7 +3257,7 @@
   
     case WM_NCACTIVATE:
       /* Windows doesn't send us focus messages when putting up and
-	 taking down a system popup dialog as for Ctrl-Alt-Del on Win95.
+	 taking down a system popup dialog as for Ctrl-Alt-Del on Windows 95.
 	 The only indication we get that something happened is receiving
 	 this message afterwards.  So this is a good time to reset our
 	 keyboard modifiers' state. */
@@ -3371,7 +3371,7 @@
 {
   MSG msg;
 
-  PostThreadMessage (dwWinThreadId, WM_EMACS_CREATEWINDOW, (WPARAM)f, 0);
+  PostThreadMessage (dwWindowsThreadId, WM_EMACS_CREATEWINDOW, (WPARAM)f, 0);
   GetMessage (&msg, NULL, WM_EMACS_DONE, WM_EMACS_DONE);
 }
 
@@ -3435,7 +3435,7 @@
 {
   Lisp_Object icon_x, icon_y;
 
   /* Set the position of the icon.  Note that win95 groups all
      icons in the tray.  */
   icon_x = x_get_arg (parms, Qicon_left, 0, 0, number);
   icon_y = x_get_arg (parms, Qicon_top, 0, 0, number);
@@ -2680,7 +2680,7 @@
 }
 
-/* GetKeyState and MapVirtualKey on Win95 do not actually distinguish
+/* GetKeyState and MapVirtualKey on Windows 95 do not actually distinguish
    between left and right keys as advertised.  We test for this
    support dynamically, and set a flag when the support is absent.  If
@@ -3435,7 +3435,7 @@
   Lisp_Object icon_x, icon_y;
 
-  /* Set the position of the icon.  Note that win95 groups all
+  /* Set the position of the icon.  Note that Windows 95 groups all
      icons in the tray.  */
   icon_x = x_get_arg (parms, Qicon_left, 0, 0, number);
--- a/src/w32term.c	Mon Jan 20 00:34:34 1997 +0000
+++ b/src/w32term.c	Mon Jan 20 00:38:22 1997 +0000
@@ -1,4 +1,4 @@
-/* Implementation of GUI terminal on the Win32 API.
+/* Implementation of GUI terminal on the Microsoft W32 API.
    Copyright (C) 1989, 1993, 1994, 1995 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -89,8 +89,8 @@
 static int curs_x;
 static int curs_y;
 
-DWORD dwWinThreadId = 0;
-HANDLE hWinThread = NULL;
+DWORD dwWindowsThreadId = 0;
+HANDLE hWindowsThread = NULL;
 DWORD dwMainThreadId = 0;
 HANDLE hMainThread = NULL;
 
@@ -1802,7 +1802,7 @@
 {
   MSG msg;
   
-  PostThreadMessage (dwWinThreadId, WM_EMACS_CREATESCROLLBAR, (WPARAM) f, 
+  PostThreadMessage (dwWindowsThreadId, WM_EMACS_CREATESCROLLBAR, (WPARAM) f, 
 		     (LPARAM) bar);
   GetMessage (&msg, NULL, WM_EMACS_DONE, WM_EMACS_DONE);
   
@@ -2331,7 +2331,7 @@
 {
   unsigned int code = MapVirtualKey (wparam, 2);
 
   /* Win95 returns 0x8000, NT returns 0x80000000.  */
   if ((code & 0x8000) || (code & 0x80000000))
     return 1;
   else
@@ -2350,12 +2350,12 @@
    EXPECTED is nonzero if the caller knows input is available.  
 
    Some of these messages are reposted back to the message queue since the
-   system calls the winproc directly in a context where we cannot return the
-   data nor can we guarantee the state we are in.  So if we dispatch  them
+   system calls the windows proc directly in a context where we cannot return 
+   the data nor can we guarantee the state we are in.  So if we dispatch  them
    we will get into an infinite loop.  To prevent this from ever happening we
    will set a variable to indicate we are in the read_socket call and indicate
-   which message we are processing since the winproc gets called recursively with different
-   messages by the system.
+   which message we are processing since the windows proc gets called 
+   recursively with different messages by the system.
 */
 
 int
@@ -3791,7 +3791,7 @@
 
 /* Set up use of W32.  */
 
-DWORD win_msg_worker ();
+DWORD windows_msg_worker ();
 
 w32_initialize ()
 {
@@ -3846,23 +3846,23 @@
 
     PeekMessage (&msg, NULL, 0, 0, PM_NOREMOVE);
 
-    hWinThread = CreateThread (NULL, 0, 
-			       (LPTHREAD_START_ROUTINE) win_msg_worker, 
-			       0, 0, &dwWinThreadId);
+    hWindowsThread = CreateThread (NULL, 0, 
+			       (LPTHREAD_START_ROUTINE) windows_msg_worker, 
+			       0, 0, &dwWindowsThreadId);
 
     GetMessage (&msg, NULL, WM_EMACS_DONE, WM_EMACS_DONE);
   }
   
   /* It is desirable that mainThread should have the same notion of
-     focus window and active window as winThread.  Unfortunately, the
+     focus window and active window as windowsThread.  Unfortunately, the
      following call to AttachThreadInput, which should do precisely what
      we need, causes major problems when Emacs is linked as a console
      program.  Unfortunately, we have good reasons for doing that, so
-     instead we need to send messages to winThread to make some API
+     instead we need to send messages to windowsThread to make some API
      calls for us (ones that affect, or depend on, the active/focus
      window state.  */
 #ifdef ATTACH_THREADS
-  AttachThreadInput (dwMainThreadId, dwWinThreadId, TRUE);
+  AttachThreadInput (dwMainThreadId, dwWindowsThreadId, TRUE);
 #endif
 }
 
@@ -2331,7 +2331,7 @@
   unsigned int code = MapVirtualKey (wparam, 2);
 
-  /* Win95 returns 0x8000, NT returns 0x80000000.  */
+  /* Windows 95 returns 0x8000, NT returns 0x80000000.  */
   if ((code & 0x8000) || (code & 0x80000000))
     return 1;